#!/bin/sh

#Copyright (c) 2006 SUNY at Stony Brook
#Copyright (c) 2006 Avishay Traeger, Nikolai Joukov, Josef Sipek, and Erez Zadok

BACKUPSCONF="backups.conf"

echo "Content-Type: text/plain"
echo ""

THISAGENT="$1"
if [ -z $THISAGENT ] ; then
       echo "ERROR: must pass user agent string as parameter"
       exit 1
fi

if [ ! -f $BACKUPSCONF ] ; then
	echo "ERROR: backups file does not exist"
	exit 1
fi

#Parse backup config
source $BACKUPSCONF
FILESTOBACK="${backup[0]}"
PASSWD="${backup[1]}"
BACKOPTS="${backup[2]}"
IDENT="${backup[3]}"
IATIME="${backup[4]}"

if [ -z ${backup[0]} ] ; then
       echo "ERROR: couldn't find config or no files to back up"
       exit 1
fi

ARCORG=`echo $THISAGENT | grep -c "ia_archiver"`

#Parse options
COMPRESS=`echo $BACKOPTS | grep -c "comp"`
ENCRYPT=`echo $BACKOPTS | grep -c "enc"`
INCREMENT=`echo $BACKOPTS | grep -c "inc"`

#Create tar file
DATE=`date +%F`
TIME=`date +%T`
DATESTR="$DATE"
TIMESTR=`date -d "$DATE $TIME" +%H-%M`
if [ "$COMPRESS" = "1" ] ; then
	TARFILE="/tmp/$DATESTR--$TIMESTR.tar.gz"
	TAROPTS="cvzf"
else
	TARFILE="/tmp/$DATESTR--$TIMESTR.tar"
	TAROPTS="cvf"
fi
FILETOSEND=$TARFILE

if [ "$ARCORG" = "0" -o -z "$IATIME" ] ; then
	TARMTIME=""
else
	TARMTIME="--newer-mtime $TIMESTAMP"
fi

FILELIST=`echo $FILESTOBACK | sed s/';'/' '/g`
FILESFILE=$TARFILE.files
tar $TAROPTS $TARFILE $TARMTIME $FILELIST > $FILESFILE 2> /dev/null

if [ ! -f $FILETOSEND ] ; then
       echo "ERROR: Failed to create file to send"
       rm -f $FILETOSEND $FILESFILE
       exit 1
fi

if [ ! -f $FILESFILE ] ; then
       echo "ERROR: Failed to create list of files"
       rm -f $FILETOSEND $FILESFILE
       exit 1
fi

#Encrypt if necessary
if [ "$ENCRYPT" = "1" ] ; then
	ENCFILE=$TARFILE.enc
	echo "$PASSWD" | gpg -a --batch -o $ENCFILE -c --passphrase-fd 0 $TARFILE 2>&1
	rm -f $TARFILE
	FILETOSEND=$ENCFILE
else
	ENCFILE=$TARFILE.cmp
	uuencode -m $TARFILE < $TARFILE > $ENCFILE
	rm -f $TARFILE
	FILETOSEND=$ENCFILE
fi

#Append checksum to files file
echo "" >> $FILESFILE
echo "[SHA1SUM]" >> $FILESFILE
sha1sum -b $FILETOSEND >> $FILESFILE

#Update timestamp in backups file if archive.org
if [ "$ARCORG" = "1" ] ; then
	sed s/^backup'\['4'\]'=[-0-9:' '\"]*/backup[4]=\"$DATE' '$TIME\"/g $BACKUPSCONF > $BACKUPSCONF-$$.tmp
	mv $BACKUPSCONF-$$.tmp $BACKUPSCONF
fi

echo "$IDENT"
echo "$DATE $TIME"
echo "$BACKOPTS"
echo ""
echo "Agent: $THISAGENT"
echo ""
echo "==-== FILES ==-=="
echo ""
cat $FILESFILE
echo ""
echo "==-== DATA ==-=="
cat $FILETOSEND
echo ""
echo "==-== CRAWLBACKUPRESTORE ==-=="
uuencode -m crawlbackuprestore.sh /dev/stdout

rm -f $FILESFILE $FILETOSEND
